@@ -1,17 +1,17 @@
 """Dump all global configs here or whatever is not decided here."""
 from __future__ import annotations
 
-from typing import Type
+from typing import Type, Union
 
 from pydantic import BaseModel, Field, field_validator
 
-# from omnivault.transformer.utils.device import get_device
-# import torch
+__all__ = ["MaybeGlobal"]
 
 
 class MaybeGlobal(BaseModel):
     seed: int = Field(default=42, description="The seed for reproducibility.")
     debug: bool = Field(default=False, description="Debug mode.")
+    debug_samples: Union[int, None] = Field(default=256, description="Number of samples to debug.")
 
     @field_validator("seed")
     @classmethod
